@@ -1,22 +1,19 @@
 """
-Holds the Conllable interface, which is a marker interface to show that a class
-is a Conll object, such as a treebank, sentence, or token, and therefore has a
-conll method.
+The Conllable interface is a marker interface to show that a class is in the
+Conll object domain, such as a treebank (Conll in this library), sentence, or
+token, and therefore has a conll method.
 """
 
 import abc
 
 
-class Conllable:
+class Conllable(metaclass=abc.ABCMeta):
     """
     A Conllable mixin to indicate that the component can be converted into a
     CoNLL representation.
     """
-
-    __metaclass__ = abc.ABCMeta
-
     @abc.abstractmethod
-    def conll(self):
+    def conll(self) -> str:
         """
         Provides a conll representation of the component.
 
